==> chaosmesh-model-5.7.4-sources.jar: io/fabric8/chaosmesh/v1alpha1/AwsChaosBuilder.java <==
package io.fabric8.chaosmesh.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class AwsChaosBuilder extends io.fabric8.chaosmesh.v1alpha1.AwsChaosFluentImpl<io.fabric8.chaosmesh.v1alpha1.AwsChaosBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.chaosmesh.v1alpha1.AwsChaos,io.fabric8.chaosmesh.v1alpha1.AwsChaosBuilder>{
  public AwsChaosBuilder() {
    this(false);
  }
  public AwsChaosBuilder(java.lang.Boolean validationEnabled) {
    this(new AwsChaos(), validationEnabled);
  }
  public AwsChaosBuilder(io.fabric8.chaosmesh.v1alpha1.AwsChaosFluent<?> fluent) {
    this(fluent, false);
  }
  public AwsChaosBuilder(io.fabric8.chaosmesh.v1alpha1.AwsChaosFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new AwsChaos(), validationEnabled);
  }
  public AwsChaosBuilder(io.fabric8.chaosmesh.v1alpha1.AwsChaosFluent<?> fluent,io.fabric8.chaosmesh.v1alpha1.AwsChaos instance) {
    this(fluent, instance, false);
  }
  public AwsChaosBuilder(io.fabric8.chaosmesh.v1alpha1.AwsChaosFluent<?> fluent,io.fabric8.chaosmesh.v1alpha1.AwsChaos instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withStatus(instance.getStatus()); 
    this.validationEnabled = validationEnabled; 
  }
  public AwsChaosBuilder(io.fabric8.chaosmesh.v1alpha1.AwsChaos instance) {
    this(instance,false);
  }
  public AwsChaosBuilder(io.fabric8.chaosmesh.v1alpha1.AwsChaos instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.chaosmesh.v1alpha1.AwsChaosFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.chaosmesh.v1alpha1.AwsChaos build() {
    AwsChaos buildable = new AwsChaos(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    AwsChaosBuilder that = (AwsChaosBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> chaosmesh-model-6.0.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/AwsChaosBuilder.java <==
package io.fabric8.chaosmesh.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class AwsChaosBuilder extends AwsChaosFluentImpl<AwsChaosBuilder> implements VisitableBuilder<AwsChaos,AwsChaosBuilder>{
  public AwsChaosBuilder() {
    this(false);
  }
  public AwsChaosBuilder(Boolean validationEnabled) {
    this(new AwsChaos(), validationEnabled);
  }
  public AwsChaosBuilder(AwsChaosFluent<?> fluent) {
    this(fluent, false);
  }
  public AwsChaosBuilder(AwsChaosFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new AwsChaos(), validationEnabled);
  }
  public AwsChaosBuilder(AwsChaosFluent<?> fluent,AwsChaos instance) {
    this(fluent, instance, false);
  }
  public AwsChaosBuilder(AwsChaosFluent<?> fluent,AwsChaos instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withStatus(instance.getStatus()); 
    this.validationEnabled = validationEnabled; 
  }
  public AwsChaosBuilder(AwsChaos instance) {
    this(instance,false);
  }
  public AwsChaosBuilder(AwsChaos instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.validationEnabled = validationEnabled; 
  }
  AwsChaosFluent<?> fluent;
  Boolean validationEnabled;
  public AwsChaos build() {
    AwsChaos buildable = new AwsChaos(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
    return buildable;
  }
  
}
